<?php
/**
 * Copyright 2023 © Pinpoint Designs. All rights reserved.
 */
namespace Pinpoint\FileUpload\Controller\Adminhtml\Wysiwyg\Images;

use Magento\Backend\App\Action;
use Magento\Cms\Helper\Wysiwyg\Images;
use Magento\Framework\Controller\Result\Raw;
use Magento\Framework\Controller\Result\RawFactory;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Registry;
use Magento\Framework\View\Asset\Repository;

/**
 * Class Thumbnail
 * @package Pinpoint\FileUpload\Controller\Adminhtml\Wysiwyg\Images
 */
class Thumbnail extends \Magento\Cms\Controller\Adminhtml\Wysiwyg\Images\Thumbnail
{
    /**
     * @var string
     */
    const PDF_ICON = 'Pinpoint_FileUpload::images/pdf-icon.png';
    const MP4_ICON = 'Pinpoint_FileUpload::images/mp4-icon.png';
    const XLSX_ICON = 'Pinpoint_FileUpload::images/xlsx-icon.png';
    const CSV_ICON = 'Pinpoint_FileUpload::images/csv-icon.png';
    const PPT_ICON = 'Pinpoint_FileUpload::images/pptx-icon.png';
    const DOC_ICON = 'Pinpoint_FileUpload::images/doc-icon.png';
    const MP3_ICON = 'Pinpoint_FileUpload::images/mp3-icon.png';
    const TXT_ICON = 'Pinpoint_FileUpload::images/txt-icon.png';


    /**
     * @var Repository
     */
    protected Repository $assetRepository;

    /**
     * @var Images
     */
    protected Images $images;

    /**
     * Thumbnail constructor.
     * @param Action\Context $context
     * @param Registry       $coreRegistry
     * @param RawFactory     $resultRawFactory
     * @param Repository     $assetRepository
     * @param Images         $images
     */
    public function __construct(
        Action\Context $context,
        Registry $coreRegistry,
        RawFactory $resultRawFactory,
        Repository $assetRepository,
        Images $images
    ) {
        $this->assetRepository = $assetRepository;
        $this->images = $images;
        parent::__construct($context, $coreRegistry, $resultRawFactory);
    }

    /**
     * @return Raw
     * @throws LocalizedException
     */
    public function execute(): Raw
    {
        $file = $this->getRequest()->getParam('file');
        $file = $this->images->idDecode($file);
        $params = [
            'area' => 'adminhtml'
        ];

        switch (pathinfo($file, PATHINFO_EXTENSION)) {
            case "pdf":
                $icon = self::PDF_ICON;
                break;
            case "mp4":
                $icon = self::MP4_ICON;
                break;
            case "xlsx":
                $icon = self::XLSX_ICON;
                break;
            case "csv":
                $icon = self::CSV_ICON;
                break;
            case "ppt":
            case "pptx":
                $icon = self::PPT_ICON;
                break;
            case "doc":
            case "docx":
                $icon = self::DOC_ICON;
                break;
            case "mp3":
                $icon = self::MP3_ICON;
                break;
            case "txt":
                $icon = self::TXT_ICON;
                break;
            default:
                return parent::execute();
        }
        $asset = $this->assetRepository->createAsset($icon, $params);
        $resultRaw = $this->resultRawFactory->create();
        $resultRaw->setHeader('Content-Type', 'image/' . $asset->getContentType());
        $resultRaw->setContents($asset->getContent());
        return $resultRaw;
    }
}
